function [sizeAvg,densityAvg,flow]=bubbleTrap(file,start,duration)
tic
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                             Parameters
%

% Filter parameters will need adjustment depending on lighting and time 
% Bubble height threshold and imgStart depend on size of cropped frame
%
% change the below parameters to appropriate values
bwthresh = 120; %filter threshold
areaFilt_min = 10^2; %minimum area threshold
areaFilt_max = 10^5; %maximum area threshold
bubbleH_thresh = 18; %bubble height threshold
imgStart = 0.084; %left edge of image in figure used for annotation fxn  


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% import video file
[cropped,time,frames]=importVideo(file,start,duration);
toc

% analysis for each frame
  figure()
for(i=1:frames)
    
    %copy cropped image
    data=cropped(:,:,:,i);
    %filter the image
    data = filterImage(data,bwthresh,areaFilt_min,areaFilt_max);
    
    %find bubbles
    [data,marks,x]=markImage(data,bubbleH_thresh);
    
    %find bubble size and density
    [points,size,density]=measureImage(marks,x);
    
    %save size and density for each frame in vector
    sizeVec(i,1)=size;
    sizeVec(i,2)=time(i);
    densityVec(i,1)=density;
    
    
    %save all points in matrix
    M(i,1)=points(1);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                            bubble verification function
    % this section is used to verify the analysis by overlaying bubble edge
    % marks onto filtered images during analysis and can be commented out
    % to speed up analysis after verification
    imshow(data);
    Len = 1-imgStart*2;
    for(j=1:length(points))
        annotation('line',[imgStart+(points(1,j)*(Len/x)),imgStart+(points(1,j)*(Len/x))],[0,1],'Color','red');
        drawnow
    end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    disp(['time is ',num2str(time(i))]);
    
end


%Size statistics in uL and density in percent
sizeAvg=sum(sizeVec(:,1))/length(sizeVec(:,1));
sizemin = min(sizeVec(:,1)) 
sizemax = max(sizeVec(:,1)) 
med = median(sizeVec(:,1)) 
stddev = std(sizeVec(:,1))
densityAvg = nanmean(densityVec)

%flow rate in mL/min
flow=calculateFlowrate(M,time,x);

end