function [flowrate]=calculateFlowrate(pointVec,timeVec,x)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                              Parameters
% mm to pixel conversion factor will need to be changed depending on camera
% position. Conversion currenly assumes a 75mm wide frame, but can be
% changed to any value below.

mm_pixel = 75/x; %mm to pixel ratio 
tube_r = 0.3969; %tubing inner radius in mm

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%calculate distance mark moves between frames
for(i=1:length(pointVec)-1)
    dPointVec(i,1)=pointVec(i+1)-pointVec(i);
    dTimeVec(i,1)=abs(timeVec(i)-timeVec(i+1));
end

%remove negative values (from when bubble leaves frame)
dPointVec = dPointVec(dPointVec>=0);

%calculate averages
avgPoint = mean(dPointVec);
avgTime = mean(dTimeVec);

%convert pixels to mm
avgPoint = avgPoint*mm_pixel;

%multiply by x-sectional area of tubing
avgPoint = avgPoint*pi()*(tube_r^2);

flowrate =((avgPoint/avgTime)/1000)*60;

end