function [pointVec,size,density]=measureImage(pointVec,x)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                 Parameters
% mm to pixel conversion factor will need to be changed depending on camera
% position. Conversion currenly assumes a 75mm wide frame, but can be
% changed to any value below.

mm_pixel = 75/x; %mm to pixel ratio
tube_r = 0.3969; %tubing inner radius in mm

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%ignore markers at ends:
for(i=1:length(pointVec))
    if(pointVec(i)== 1)
        pointVec(i)= 0;
        pointVec(i+1)=0;
    elseif(pointVec(i)==x)
        pointVec(i)=0;
        pointVec(i-1)=0;
    end
end

%remove zero elements in vector
pointVec=nonzeros(pointVec)';

%initialize storage vector for section lengths
lengthvec = zeros(length(pointVec))';

%calculate length of spaces
for(i=1:length(pointVec)-1)
    lengthVec(1,i)=pointVec(1,i+1)-pointVec(1,i);
end

%divide into water and air
air=lengthVec(1,1:2:end); %odd indicies are bubbles
water=lengthVec(1,2:2:end); %even indicies are water plugs

%get average lenght of water and air
waterAvg=sum(water)/length(water);
airAvg=sum(air)/length(air);


%convert pixels to mm
size=(airAvg*mm_pixel);
%multiply by x-sectional area of tubing 
size=size*pi()*(tube_r^2);
%calulate density in percent of air
density=airAvg/(airAvg+waterAvg)*100;

end